@@ -14,7 +14,7 @@ from tstoolbox import tsutils
 from tsgettoolbox import utils
 
 _UNITS_MAP = {
-    "NLDAS:NLDAS_FORA0125_H.002:APCPsfc": ["Precipitation hourly total", "kg/m2"],
+    "NLDAS:NLDAS_FORA0125_H.002:APCPsfc": ["Precipitation hourly total", "mm"],
     "NLDAS:NLDAS_FORA0125_H.002:DLWRFsfc": [
         "Surface DW longwave radiation flux",
         "W/m2",
@@ -23,7 +23,7 @@ _UNITS_MAP = {
         "Surface DW shortwave radiation flux",
         "W/m2",
     ],
-    "NLDAS:NLDAS_FORA0125_H.002:PEVAPsfc": ["Potential evaporation", "kg/m2"],
+    "NLDAS:NLDAS_FORA0125_H.002:PEVAPsfc": ["Potential evaporation", "mm"],
     "NLDAS:NLDAS_FORA0125_H.002:SPFH2m": [
         "2-m above ground specific humidity",
         "kg/kg",
@@ -31,66 +31,66 @@ _UNITS_MAP = {
     "NLDAS:NLDAS_FORA0125_H.002:TMP2m": ["2-m above ground temperature", "K"],
     "NLDAS:NLDAS_FORA0125_H.002:UGRD10m": ["10-m above ground zonal wind", "m/s"],
     "NLDAS:NLDAS_FORA0125_H.002:VGRD10m": ["10-m above ground meridional wind", "m/s"],
-    "NLDAS:NLDAS_NOAH0125_H.002:EVPsfc": ["Total evapotranspiration", "kg/m2"],
+    "NLDAS:NLDAS_NOAH0125_H.002:EVPsfc": ["Total evapotranspiration", "mm"],
     "NLDAS:NLDAS_NOAH0125_H.002:GFLUXsfc": ["Ground heat flux", "W/m2"],
     "NLDAS:NLDAS_NOAH0125_H.002:LHTFLsfc": ["Latent heat flux", "W/m2"],
     "NLDAS:NLDAS_NOAH0125_H.002:SHTFLsfc": ["Sensible heat flux", "W/m2"],
     "NLDAS:NLDAS_NOAH0125_H.002:SSRUNsfc": [
         "Surface runoff (non-infiltrating)",
-        "kg/m2",
+        "mm",
     ],
-    "NLDAS:NLDAS_NOAH0125_H.002:BGRUNsfc": ["Subsurface runoff (baseflow)", "kg/m2"],
+    "NLDAS:NLDAS_NOAH0125_H.002:BGRUNsfc": ["Subsurface runoff (baseflow)", "mm"],
     "NLDAS:NLDAS_NOAH0125_H.002:SOILM0-10cm": [
         "0-10 cm soil moisture content",
-        "kg/m2",
+        "mm",
     ],
     "NLDAS:NLDAS_NOAH0125_H.002:SOILM0-100cm": [
         "0-100 cm soil moisture content",
-        "kg/m2",
+        "mm",
     ],
     "NLDAS:NLDAS_NOAH0125_H.002:SOILM0-200cm": [
         "0-200 cm soil moisture content",
-        "kg/m2",
+        "mm",
     ],
     "NLDAS:NLDAS_NOAH0125_H.002:SOILM10-40cm": [
         "10-40 cm soil moisture content",
-        "kg/m2",
+        "mm",
     ],
     "NLDAS:NLDAS_NOAH0125_H.002:SOILM40-100cm": [
         "40-100 cm soil moisture content",
-        "kg/m2",
+        "mm",
     ],
     "NLDAS:NLDAS_NOAH0125_H.002:SOILM100-200cm": [
         "100-200 cm soil moisture content",
-        "kg/m2",
+        "mm",
     ],
     "NLDAS:NLDAS_NOAH0125_H.002:TSOIL0-10cm": ["0-10 cm soil temperature", "K"],
     "GLDAS2:GLDAS_NOAH025_3H_v2.1:AvgSurfT_inst": [
         "Average surface skin temperature",
         "K",
     ],
-    "GLDAS2:GLDAS_NOAH025_3H_v2.1:Evap_tavg": ["Evapotranspiration", "kg/m2/s"],
+    "GLDAS2:GLDAS_NOAH025_3H_v2.1:Evap_tavg": ["Evapotranspiration", "mm/s"],
     "GLDAS2:GLDAS_NOAH025_3H_v2.1:Psurf_f_inst": ["Surface air pressure", "Pa"],
     "GLDAS2:GLDAS_NOAH025_3H_v2.1:Qair_f_inst": ["Specific humidity", "kg/kg"],
-    "GLDAS2:GLDAS_NOAH025_3H_v2.1:Qs_acc": ["Storm surface runoff", "kg/m2"],
-    "GLDAS2:GLDAS_NOAH025_3H_v2.1:Qsb_acc": ["Baseflow-groundwater runoff", "kg/m2"],
+    "GLDAS2:GLDAS_NOAH025_3H_v2.1:Qs_acc": ["Storm surface runoff", "mm"],
+    "GLDAS2:GLDAS_NOAH025_3H_v2.1:Qsb_acc": ["Baseflow-groundwater runoff", "mm"],
     "GLDAS2:GLDAS_NOAH025_3H_v2.1:Rainf_f_tavg": [
         "Total precipitation rate",
-        "kg/m2/s",
+        "mm/s",
     ],
-    "GLDAS2:GLDAS_NOAH025_3H_v2.1:Rainf_tavg": ["Rain precipitation rate", "kg/m2/s"],
-    "GLDAS2:GLDAS_NOAH025_3H_v2.1:Snowf_tavg": ["Snow precipitation rate", "kg/m2/s"],
+    "GLDAS2:GLDAS_NOAH025_3H_v2.1:Rainf_tavg": ["Rain precipitation rate", "mm/s"],
+    "GLDAS2:GLDAS_NOAH025_3H_v2.1:Snowf_tavg": ["Snow precipitation rate", "mm/s"],
     "GLDAS2:GLDAS_NOAH025_3H_v2.1:SoilMoi0_10cm_inst": [
         "Soil moisture content (0-10 cm)",
-        "kg/m2",
+        "mm",
     ],
     "GLDAS2:GLDAS_NOAH025_3H_v2.1:SoilMoi10_40cm_inst": [
         "Soil moisture content (10-40 cm)",
-        "kg/m2",
+        "mm",
     ],
     "GLDAS2:GLDAS_NOAH025_3H_v2.1:SoilMoi40_100cm_inst": [
         "Soil moisture content (40-100 cm)",
-        "kg/m2",
+        "mm",
     ],
     "GLDAS2:GLDAS_NOAH025_3H_v2.1:SoilTMP0_10cm_inst": [
         "Soil temperature (0-10 cm)",
@@ -246,11 +246,11 @@ _UNITS_MAP = {
         "Incident shortwave radiation land:average",
         "W/m2",
     ],
-    "MERRA:MST1NXMLD.520:BASEFLOW": ["Baseflow", "kg/m2/s"],
+    "MERRA:MST1NXMLD.520:BASEFLOW": ["Baseflow", "mm/s"],
     "MERRA:MST1NXMLD.520:LHLAND": ["Latent heat flux from land", "W/m2"],
-    "MERRA:MST1NXMLD.520:PRECSNO": ["Surface snowfall", "kg/m2/s"],
-    "MERRA:MST1NXMLD.520:PRECTOT": ["Total surface precipitation", "kg/m2/s"],
-    "MERRA:MST1NXMLD.520:RUNOFF": ["Overland runoff", "kg/m2/s"],
+    "MERRA:MST1NXMLD.520:PRECSNO": ["Surface snowfall", "mm/s"],
+    "MERRA:MST1NXMLD.520:PRECTOT": ["Total surface precipitation", "mm/s"],
+    "MERRA:MST1NXMLD.520:RUNOFF": ["Overland runoff", "mm/s"],
     "MERRA:MST1NXMLD.520:SFMC": ["Top soil layer soil moisture content", "m3/m3"],
     "MERRA:MST1NXMLD.520:SHLAND": ["Sensible heat flux from land", "W/m2"],
     "MERRA:MST1NXMLD.520:TSOIL1": ["Soil temperature in layer 1", "K"],
@@ -292,7 +292,7 @@ units_table = tb(
     headers=['LDAS "variable" string Description', "Units"],
 )
 
-units_table = textwrap.indent(units_table, "        ")
+units_table = textwrap.indent(units_table, "            ")
 
 
 @mando.command("ldas", formatter_class=HelpFormatter, doctype="numpy")
@@ -306,7 +306,7 @@ def ldas_cli(
     startDate=None,
     endDate=None,
 ):
-    """Download data from the Land Data Assimilation Systmem (LDAS).
+    """Download data from the Land Data Assimilation System (LDAS).
 
         This will download data from a set of water cycle related variables
         (Table 1) from the North American and Global Land Data Assimilation
@@ -502,6 +502,7 @@ def ldas_cli(
 #    startDate=[tsutils.parsedate, ["pass", []], 1],
 #    endDate=[tsutils.parsedate, ["pass", []], 1],
 # )
+@tsutils.transform_args(variable=tsutils.make_list)
 def ldas(
     lat=None,
     lon=None,
@@ -512,8 +513,6 @@ def ldas(
     endDate=None,
 ):
     r"""Download data from NLDAS or GLDAS."""
-    words = variable.split(":")
-    project = words[0]
     if lat is not None and lon is not None:
         location = "GEOM:POINT({0}, {1})".format(lon, lat)
     elif project == "NLDAS" and xindex is not None and yindex is not None:
@@ -536,63 +535,59 @@ location.  You have the grid "{project}" and "xindex={xindex}" and
             )
         )
 
-    if len(words) == 2:
-        # New style where can leave off first ":" separated field.
-        variable = ":".join([_varmap[words[0]]] + words)
-
     url = r"https://hydro1.gesdisc.eosdis.nasa.gov/daac-bin/access/timeseries.cgi"
 
-    query_params = {}
-    query_params["type"] = "asc2"
-    query_params["startDate"] = tsutils.parsedate(startDate, strftime="%Y-%m-%dT%H")
-    query_params["endDate"] = tsutils.parsedate(endDate, strftime="%Y-%m-%dT%H")
-    query_params["location"] = location
-    query_params["variable"] = variable
-
-    session = utils.requests_retry_session()
-    req = session.get(url, params=query_params)
-
-    if os.path.exists("debug_tsgettoolbox"):
-        logging.warning(req.url)
-    req.raise_for_status()
-    if b"ERROR" in req.content:
-        raise ValueError(req.content)
-
-    df = pd.read_csv(
-        BytesIO(req.content),
-        skiprows=40,
-        header=None,
-        index_col=None,
-        delim_whitespace=True,
-        na_values=[-9999, -9999.0],
-    )
-    df.drop(df.index[-1], axis="rows", inplace=True)
-    if len(df.columns) == 3:
-        df["dt"] = df[0] + "T" + df[1]
-        df["dt"] = pd.to_datetime(df["dt"])
-        df.set_index("dt", inplace=True)
-        df.drop([0, 1], axis="columns", inplace=True)
-    else:
-        df[0] = pd.to_datetime(df[0])
-        df.set_index(0, inplace=True)
-    variable_name = query_params["variable"].split(":")[-1]
-    unit = _UNITS_MAP[query_params["variable"]][1]
-    df.columns = ["{0}:{1}".format(variable_name, unit)]
-    df.index.name = "Datetime:UTC"
-    try:
-        return df.tz_localize("UTC")
-    except TypeError:  # Already UTC
-        return df
     ndf = pd.DataFrame()
-    for cnt, var in enumerate(tsutils.make_list(variable)):
-        r = ldas(
-            variable=var,
-            lat=lat,
-            lon=lon,
-            startDate=startDate,
-            endDate=endDate,
+    for var in variable:
+        words = var.split(":")
+        project = words[0]
+        nvariable = var
+        if len(words) == 2:
+            # New style where can leave off first ":" separated field.
+            nvariable = ":".join([_varmap[words[0]]] + words)
+
+        query_params = {}
+        query_params["type"] = "asc2"
+        query_params["startDate"] = tsutils.parsedate(startDate, strftime="%Y-%m-%dT%H")
+        query_params["endDate"] = tsutils.parsedate(endDate, strftime="%Y-%m-%dT%H")
+        query_params["location"] = location
+        query_params["variable"] = nvariable
+
+        session = utils.requests_retry_session()
+        req = session.get(url, params=query_params)
+
+        if os.path.exists("debug_tsgettoolbox"):
+            logging.warning(req.url)
+        req.raise_for_status()
+        if b"ERROR" in req.content:
+            raise ValueError(req.content)
+
+        df = pd.read_csv(
+            BytesIO(req.content),
+            skiprows=40,
+            header=None,
+            index_col=None,
+            delim_whitespace=True,
+            na_values=[-9999, -9999.0],
         )
-        ndf = ndf.join(r, how="outer", rsuffix="_{0}".format(cnt))
+        df.drop(df.index[-1], axis="rows", inplace=True)
+        if len(df.columns) == 3:
+            df["dt"] = df[0] + "T" + df[1]
+            df["dt"] = pd.to_datetime(df["dt"])
+            df.set_index("dt", inplace=True)
+            df.drop([0, 1], axis="columns", inplace=True)
+        else:
+            df[0] = pd.to_datetime(df[0])
+            df.set_index(0, inplace=True)
+        variable_name = query_params["variable"].split(":")[-1]
+        unit = _UNITS_MAP[query_params["variable"]][1]
+        df.columns = ["{0}:{1}".format(variable_name, unit)]
+        df.index.name = "Datetime:UTC"
+        try:
+            return df.tz_localize("UTC")
+        except TypeError:  # Already UTC
+            pass
+        ndf = ndf.join(df, how="outer")
 
     return ndf
 
