@@ -15,20 +15,21 @@ from .functions.cpc import cpc
 from .functions.daymet import daymet
 from .functions.fawn import fawn
 from .functions.ldas import ldas
+from .functions.metdata import metdata
 from .functions.modis import modis
-from .functions.ncdc import ncdc_annual
-from .functions.ncdc import ncdc_ghcnd
-from .functions.ncdc import ncdc_ghcnd_ftp
-from .functions.ncdc import ncdc_ghcndms
-from .functions.ncdc import ncdc_gs
-from .functions.ncdc import ncdc_nexrad2
-from .functions.ncdc import ncdc_nexrad3
-from .functions.ncdc import ncdc_normal_ann
-from .functions.ncdc import ncdc_normal_dly
-from .functions.ncdc import ncdc_normal_hly
-from .functions.ncdc import ncdc_normal_mly
-from .functions.ncdc import ncdc_precip_15
-from .functions.ncdc import ncdc_precip_hly
+from .functions.ncei import ncei_annual
+from .functions.ncei import ncei_ghcnd
+from .functions.ncei import ncei_ghcnd_ftp
+from .functions.ncei import ncei_ghcndms
+from .functions.ncei import ncei_gs
+from .functions.ncei import ncei_nexrad2
+from .functions.ncei import ncei_nexrad3
+from .functions.ncei import ncei_normal_ann
+from .functions.ncei import ncei_normal_dly
+from .functions.ncei import ncei_normal_hly
+from .functions.ncei import ncei_normal_mly
+from .functions.ncei import ncei_precip_15
+from .functions.ncei import ncei_precip_hly
 from .functions.ndbc import ndbc
 from .functions.nwis import epa_wqp
 from .functions.nwis import nwis
@@ -54,14 +55,14 @@ try:
 except ImportError:
     from argparse import RawTextHelpFormatter as HelpFormatter
 
-from tstoolbox import tsutils
-
 warnings.filterwarnings("ignore")
 
 
 @mando.command()
 def about():
     r"""Print out information about tsgettoolbox and the system."""
+    from tstoolbox import tsutils
+
     tsutils.about(__name__)
 
 
