@@ -72,10 +72,11 @@ api_key = ReplaceThisStringWithYourKey
 
     return api_key
 
+
 def requests_retry_session(
     retries=3,
-    backoff_factor=0.3,
-    status_forcelist=(500, 502, 504),
+    backoff_factor=0.5,
+    status_forcelist=(500, 502, 503, 504),
     session=None,
 ):
     session = session or requests.Session()
@@ -87,6 +88,6 @@ def requests_retry_session(
         status_forcelist=status_forcelist,
     )
     adapter = HTTPAdapter(max_retries=retry)
-    session.mount('http://', adapter)
-    session.mount('https://', adapter)
+    session.mount("http://", adapter)
+    session.mount("https://", adapter)
     return session
